@@ -30,14 +30,39 @@
 
 #include <libavcodec/avcodec.h>
 #include <libavformat/avformat.h>
+#include <libavfilter/avfiltergraph.h>
 
 #include "gstav.h"
 #include "gstavutils.h"
 
+#ifdef GST_LIBAV_ENABLE_GPL
+#define LICENSE "GPL"
+#else
+#define LICENSE "LGPL"
+#endif
+
 GST_DEBUG_CATEGORY (ffmpeg_debug);
+GST_DEBUG_CATEGORY (CAT_PERFORMANCE);
 
 static GMutex gst_avcodec_mutex;
 
+/*
+ * Check for FFmpeg-provided libavcodec/format
+ */
+static inline gboolean
+gst_ffmpeg_avcodec_is_ffmpeg (void)
+{
+  guint av_version = avutil_version ();
+
+  GST_DEBUG ("Using libavcodec version %d.%d.%d",
+      av_version >> 16, (av_version & 0x00ff00) >> 8, av_version & 0xff);
+
+  /* FFmpeg *_MICRO versions start at 100 and Libav's at 0 */
+  if ((av_version & 0xff) < 100)
+    return FALSE;
+
+  return TRUE;
+}
 
 int
 gst_ffmpeg_avcodec_open (AVCodecContext * avctx, AVCodec * codec)
@@ -118,14 +143,22 @@ static gboolean
 plugin_init (GstPlugin * plugin)
 {
   GST_DEBUG_CATEGORY_INIT (ffmpeg_debug, "libav", 0, "libav elements");
-#ifndef GST_DISABLE_GST_DEBUG
+  GST_DEBUG_CATEGORY_GET (CAT_PERFORMANCE, "GST_PERFORMANCE");
 
+  /* Bail if not FFmpeg. We can no longer ensure operation with Libav */
+  if (!gst_ffmpeg_avcodec_is_ffmpeg ()) {
+    GST_ERROR_OBJECT (plugin,
+        "Incompatible, non-FFmpeg libavcodec/format found");
+    return FALSE;
+  }
+#ifndef GST_DISABLE_GST_DEBUG
   av_log_set_callback (gst_ffmpeg_log_callback);
 #endif
 
   gst_ffmpeg_init_pix_fmt_info ();
 
   av_register_all ();
+  avfilter_register_all ();
 
   gst_ffmpegaudenc_register (plugin);
   gst_ffmpegvidenc_register (plugin);
@@ -149,10 +182,5 @@ GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
     GST_VERSION_MINOR,
     libav,
     "All libav codecs and formats (" LIBAV_SOURCE ")",
-    plugin_init, PACKAGE_VERSION,
-#ifdef GST_LIBAV_ENABLE_GPL
-    "GPL",
-#else
-    "LGPL",
-#endif
+    plugin_init, PACKAGE_VERSION, LICENSE,
     "libav", "http://www.libav.org")
